@@ -248,9 +248,9 @@ class TestXLIFF2POCommand(test_convert.TestConvertCommand, TestXLIFF2PO):
             assert len(pofile.units) == 1
             return pofile.units[0]
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-P, --pot")
         options = self.help_check(options, "--duplicates=DUPLICATESTYLE")
 
