@@ -157,7 +157,7 @@ languages = {
     'pt': ('Portuguese', 2, '(n != 1)'),
     'pt_BR': ('Portuguese (Brazil)', 2, '(n > 1)'),
     'rm': ('Romansh', 2, '(n != 1)'),
-    'ro': ('Romanian', 3, '(n==1 ? 0 : (n==0 || (n%100 > 0 && n%100 < 20)) ? 1 : 2);'),
+    'ro': ('Romanian', 3, '(n==1 ? 0 : (n==0 || (n%100 > 0 && n%100 < 20)) ? 1 : 2)'),
     'ru': ('Russian', 3,
            '(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2)'),
     'rw': ('Kinyarwanda', 2, '(n != 1)'),
@@ -329,6 +329,220 @@ cldr_plural_categories = [
     'other',
 ]
 
+"""List of plural tags generated from CLDR 32.0.1 using
+https://github.com/WeblateOrg/language-data
+"""
+plural_tags = {
+    'af': ['one', 'other'],
+    'ak': ['one', 'other'],
+    'am': ['one', 'other'],
+    'ar': ['zero', 'one', 'two', 'few', 'many', 'other'],
+    'ars': ['zero', 'one', 'two', 'few', 'many', 'other'],
+    'as': ['one', 'other'],
+    'asa': ['one', 'other'],
+    'ast': ['one', 'other'],
+    'az': ['one', 'other'],
+    'be': ['one', 'few', 'many'],
+    'bem': ['one', 'other'],
+    'bez': ['one', 'other'],
+    'bg': ['one', 'other'],
+    'bh': ['one', 'other'],
+    'bm': ['other'],
+    'bn': ['one', 'other'],
+    'bo': ['other'],
+    'br': ['one', 'two', 'few', 'many', 'other'],
+    'brx': ['one', 'other'],
+    'bs': ['one', 'few', 'other'],
+    'ca': ['one', 'other'],
+    'ce': ['one', 'other'],
+    'ceb': ['one', 'other'],
+    'cgg': ['one', 'other'],
+    'chr': ['one', 'other'],
+    'ckb': ['one', 'other'],
+    'cs': ['one', 'few', 'other'],
+    'cy': ['zero', 'one', 'two', 'few', 'many', 'other'],
+    'da': ['one', 'other'],
+    'de': ['one', 'other'],
+    'dsb': ['one', 'two', 'few', 'other'],
+    'dv': ['one', 'other'],
+    'dz': ['other'],
+    'ee': ['one', 'other'],
+    'el': ['one', 'other'],
+    'en': ['one', 'other'],
+    'eo': ['one', 'other'],
+    'es': ['one', 'other'],
+    'et': ['one', 'other'],
+    'eu': ['one', 'other'],
+    'fa': ['one', 'other'],
+    'ff': ['one', 'other'],
+    'fi': ['one', 'other'],
+    'fil': ['one', 'other'],
+    'fo': ['one', 'other'],
+    'fr': ['one', 'other'],
+    'fur': ['one', 'other'],
+    'fy': ['one', 'other'],
+    'ga': ['one', 'two', 'few', 'many', 'other'],
+    'gd': ['one', 'two', 'few', 'other'],
+    'gl': ['one', 'other'],
+    'gsw': ['one', 'other'],
+    'gu': ['one', 'other'],
+    'guw': ['one', 'other'],
+    'gv': ['one', 'two', 'few', 'other'],
+    'ha': ['one', 'other'],
+    'haw': ['one', 'other'],
+    'he': ['one', 'two', 'many', 'other'],
+    'hi': ['one', 'other'],
+    'hr': ['one', 'few', 'other'],
+    'hsb': ['one', 'two', 'few', 'other'],
+    'hu': ['one', 'other'],
+    'hy': ['one', 'other'],
+    'ia': ['one', 'other'],
+    'id': ['other'],
+    'ig': ['other'],
+    'ii': ['other'],
+    'in': ['other'],
+    'io': ['one', 'other'],
+    'is': ['one', 'other'],
+    'it': ['one', 'other'],
+    'iu': ['one', 'two', 'other'],
+    'iw': ['one', 'two', 'many', 'other'],
+    'ja': ['other'],
+    'jbo': ['other'],
+    'jgo': ['one', 'other'],
+    'ji': ['one', 'other'],
+    'jmc': ['one', 'other'],
+    'jv': ['other'],
+    'jw': ['other'],
+    'ka': ['one', 'other'],
+    'kab': ['one', 'other'],
+    'kaj': ['one', 'other'],
+    'kcg': ['one', 'other'],
+    'kde': ['other'],
+    'kea': ['other'],
+    'kk': ['one', 'other'],
+    'kkj': ['one', 'other'],
+    'kl': ['one', 'other'],
+    'km': ['other'],
+    'kn': ['one', 'other'],
+    'ko': ['other'],
+    'ks': ['one', 'other'],
+    'ksb': ['one', 'other'],
+    'ksh': ['zero', 'one', 'other'],
+    'ku': ['one', 'other'],
+    'kw': ['zero', 'one', 'two', 'few', 'many', 'other'],
+    'ky': ['one', 'other'],
+    'lag': ['zero', 'one', 'other'],
+    'lb': ['one', 'other'],
+    'lg': ['one', 'other'],
+    'lkt': ['other'],
+    'ln': ['one', 'other'],
+    'lo': ['other'],
+    'lt': ['one', 'few', 'other'],
+    'lv': ['zero', 'one', 'other'],
+    'mas': ['one', 'other'],
+    'mg': ['one', 'other'],
+    'mgo': ['one', 'other'],
+    'mk': ['one', 'other'],
+    'ml': ['one', 'other'],
+    'mn': ['one', 'other'],
+    'mo': ['one', 'few', 'other'],
+    'mr': ['one', 'other'],
+    'ms': ['other'],
+    'mt': ['one', 'few', 'many', 'other'],
+    'my': ['other'],
+    'nah': ['one', 'other'],
+    'naq': ['one', 'two', 'other'],
+    'nb': ['one', 'other'],
+    'nd': ['one', 'other'],
+    'ne': ['one', 'other'],
+    'nl': ['one', 'other'],
+    'nn': ['one', 'other'],
+    'nnh': ['one', 'other'],
+    'no': ['one', 'other'],
+    'nqo': ['other'],
+    'nr': ['one', 'other'],
+    'nso': ['one', 'other'],
+    'ny': ['one', 'other'],
+    'nyn': ['one', 'other'],
+    'om': ['one', 'other'],
+    'or': ['one', 'other'],
+    'os': ['one', 'other'],
+    'pa': ['one', 'other'],
+    'pap': ['one', 'other'],
+    'pl': ['one', 'few', 'many'],
+    'prg': ['zero', 'one', 'other'],
+    'ps': ['one', 'other'],
+    'pt': ['one', 'other'],
+    'pt_PT': ['one', 'other'],
+    'rm': ['one', 'other'],
+    'ro': ['one', 'few', 'other'],
+    'rof': ['one', 'other'],
+    'root': ['other'],
+    'ru': ['one', 'few', 'many'],
+    'rwk': ['one', 'other'],
+    'sah': ['other'],
+    'saq': ['one', 'other'],
+    'sc': ['one', 'other'],
+    'scn': ['one', 'other'],
+    'sd': ['one', 'other'],
+    'sdh': ['one', 'other'],
+    'se': ['one', 'two', 'other'],
+    'seh': ['one', 'other'],
+    'ses': ['other'],
+    'sg': ['other'],
+    'sh': ['one', 'few', 'other'],
+    'shi': ['one', 'few', 'other'],
+    'si': ['one', 'other'],
+    'sk': ['one', 'few', 'other'],
+    'sl': ['one', 'two', 'few', 'other'],
+    'sma': ['one', 'two', 'other'],
+    'smi': ['one', 'two', 'other'],
+    'smj': ['one', 'two', 'other'],
+    'smn': ['one', 'two', 'other'],
+    'sms': ['one', 'two', 'other'],
+    'sn': ['one', 'other'],
+    'so': ['one', 'other'],
+    'sq': ['one', 'other'],
+    'sr': ['one', 'few', 'other'],
+    'ss': ['one', 'other'],
+    'ssy': ['one', 'other'],
+    'st': ['one', 'other'],
+    'sv': ['one', 'other'],
+    'sw': ['one', 'other'],
+    'syr': ['one', 'other'],
+    'ta': ['one', 'other'],
+    'te': ['one', 'other'],
+    'teo': ['one', 'other'],
+    'th': ['other'],
+    'ti': ['one', 'other'],
+    'tig': ['one', 'other'],
+    'tk': ['one', 'other'],
+    'tl': ['one', 'other'],
+    'tn': ['one', 'other'],
+    'to': ['other'],
+    'tr': ['one', 'other'],
+    'ts': ['one', 'other'],
+    'tzm': ['one', 'other'],
+    'ug': ['one', 'other'],
+    'uk': ['one', 'few', 'many'],
+    'ur': ['one', 'other'],
+    'uz': ['one', 'other'],
+    've': ['one', 'other'],
+    'vi': ['other'],
+    'vo': ['one', 'other'],
+    'vun': ['one', 'other'],
+    'wa': ['one', 'other'],
+    'wae': ['one', 'other'],
+    'wo': ['other'],
+    'xh': ['one', 'other'],
+    'xog': ['one', 'other'],
+    'yi': ['one', 'other'],
+    'yo': ['other'],
+    'yue': ['other'],
+    'zh': ['other'],
+    'zu': ['one', 'other']
+}
+
 
 def simplercode(code):
     """This attempts to simplify the given language code by ignoring country
@@ -379,9 +593,13 @@ def get_country_iso_name(country_code):
     country_code = country_code.upper()
     try:
         if len(country_code) == 2:
-            return pycountry.countries.get(alpha_2=country_code).name
-        return pycountry.countries.get(alpha_3=country_code).name
-    except KeyError:
+            country = pycountry.countries.get(alpha_2=country_code)
+        else:
+            country = pycountry.countries.get(alpha_3=country_code)
+        if hasattr(country, 'common_name'):
+            return country.common_name
+        return country.name
+    except (KeyError, AttributeError):
         return u""
 
 
@@ -389,9 +607,13 @@ def get_language_iso_name(language_code):
     """Return language ISO name."""
     try:
         if len(language_code) == 2:
-            return pycountry.languages.get(alpha_2=language_code).name
-        return pycountry.languages.get(alpha_3=language_code).name
-    except KeyError:
+            language = pycountry.languages.get(alpha_2=language_code)
+        else:
+            language = pycountry.languages.get(alpha_3=language_code)
+        if hasattr(language, 'common_name'):
+            return language.common_name
+        return language.name
+    except (KeyError, AttributeError):
         return u""
 
 
