@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2008 Zuza Software Foundation
@@ -21,12 +20,16 @@
 """This module represents the Finnish language.
 """
 
+from __future__ import unicode_literals
+
 from translate.lang import common
 
 
 class fi(common.Common):
     """This class represents Finnish."""
 
-    validaccel = u"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" + \
-                 u"1234567890" + \
-                 u"äöÄÖ"
+    validaccel = ("abcdefghijklmnopqrstuvwxyz"
+                  "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+                  "1234567890"
+                  "äö"
+                  "ÄÖ")
