@@ -22,6 +22,8 @@
 .. seealso:: http://en.wikipedia.org/wiki/Khmer_language
 """
 
+from __future__ import unicode_literals
+
 import re
 
 from translate.lang import common
@@ -30,13 +32,13 @@ from translate.lang import common
 class km(common.Common):
     """This class represents Khmer."""
 
-    khmerpunc = u"។៕៖៘"
+    khmerpunc = "។៕៖៘"
     """These marks are only used for Khmer."""
 
-    punctuation = u"".join([common.Common.commonpunc, common.Common.quotes,
-                            common.Common.miscpunc, khmerpunc])
+    punctuation = "".join([common.Common.commonpunc, common.Common.quotes,
+                           common.Common.miscpunc, khmerpunc])
 
-    sentenceend = u"!?…។៕៘"
+    sentenceend = "!?…។៕៘"
 
     sentencere = re.compile(r"""(?s)    #make . also match newlines
                             .*?         #anything, but match non-greedy
@@ -46,10 +48,10 @@ class km(common.Common):
                             """ % sentenceend, re.VERBOSE)
     #\u00a0 is non-breaking space
     puncdict = {
-        u".": u"\u00a0។",
-        u":": u"\u00a0៖",
-        u"!": u"\u00a0!",
-        u"?": u"\u00a0?",
+        ".": "\u00a0។",
+        ":": "\u00a0៖",
+        "!": "\u00a0!",
+        "?": "\u00a0?",
     }
 
     ignoretests = {
