@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2010 Zuza Software Foundation
@@ -19,24 +18,25 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 """Py2exe can't find stuff that we import dynamically, so we have this file
-just for the sake of the Windows installer to easily pick up all the stuff
-that we need and ensure they make it into the installer."""
+just for the sake of the Windows installer to easily pick up all the stuff that
+we need and ensure they make it into the installer.
+"""
 
-import catkeys
-import csvl10n
-import mo
-import omegat
-import po
-import qm
-import qph
-import tbx
-import tmx
-import ts2
-import utx
-import wordfast
-import xliff
+from . import catkeys
+from . import csvl10n
+from . import mo
+from . import omegat
+from . import po
+from . import qm
+from . import qph
+from . import tbx
+from . import tmx
+from . import ts2
+from . import utx
+from . import wordfast
+from . import xliff
 
 try:
-    import trados
+    from . import trados
 except ImportError:
     pass
