@@ -29,6 +29,7 @@ from lxml import etree
 
 from translate.lang import data
 from translate.misc.deprecation import deprecated
+from translate.misc.xml_helpers import reindent
 from translate.storage import base, lisa
 from translate.misc.multistring import multistring
 
@@ -57,7 +58,6 @@ class AndroidResourceUnit(base.TranslationUnit):
                 self.xmlelement = etree.Element("plurals")
             else:
                 self.xmlelement = etree.Element("string")
-            self.xmlelement.tail = '\n'
         if source is not None:
             self.setid(source)
         super(AndroidResourceUnit, self).__init__(source)
@@ -337,14 +337,10 @@ class AndroidResourceUnit(base.TranslationUnit):
             if self.xmlelement.tag != "plurals":
                 old_id = self.getid()
                 self.xmlelement = etree.Element("plurals")
-                self.xmlelement.tail = '\n'
                 self.setid(old_id)
 
             locale = self.gettargetlanguage().replace('_', '-').split('-')[0]
-            lang_tags = data.plural_tags.get(locale, data.plural_tags['en'])
-
-            # Get plural tags in the right order.
-            plural_tags = [tag for tag in ['zero', 'one', 'two', 'few', 'many', 'other'] if tag in lang_tags]
+            plural_tags = data.plural_tags.get(locale, data.plural_tags['en'])
 
             # Get string list to handle, wrapping non multistring/list targets into a list.
             if isinstance(target, multistring):
@@ -363,22 +359,18 @@ class AndroidResourceUnit(base.TranslationUnit):
             for entry in self.xmlelement.iterchildren():
                 self.xmlelement.remove(entry)
 
-            self.xmlelement.text = "\n\t"
+            self.xmlelement.text = "\n    "
 
             for plural_tag, plural_string in zip(plural_tags, plural_strings):
                 item = etree.Element("item")
                 item.set("quantity", plural_tag)
                 self.set_xml_text_value(plural_string, item)
-                item.tail = "\n\t"
                 self.xmlelement.append(item)
-            # Remove the tab from last item
-            item.tail = "\n"
         else:
             # Fix the root tag if mismatching
             if self.xmlelement.tag != "string":
                 old_id = self.getid()
                 self.xmlelement = etree.Element("string")
-                self.xmlelement.tail = '\n'
                 self.setid(old_id)
 
             self.set_xml_text_value(target, self.xmlelement)
@@ -416,7 +408,7 @@ class AndroidResourceUnit(base.TranslationUnit):
         else:
             return super(AndroidResourceUnit, self).getnotes(origin)
 
-    def removenotes(self):
+    def removenotes(self, origin=None):
         if ((self.xmlelement is not None) and (self.xmlelement.getparent is not None)):
             prevSibling = self.xmlelement.getprevious()
             while ((prevSibling is not None) and (prevSibling.tag is etree.Comment)):
@@ -459,6 +451,13 @@ class AndroidResourceFile(lisa.LISAfile):
         self.namespace = self.document.getroot().nsmap.get(None, None)
         self.body = self.document.getroot()
 
+    def serialize(self, out=None):
+        """Converts to a string containing the file's XML"""
+        out.write(b'<?xml version="1.0" encoding="utf-8"?>\n')
+        reindent(self.document.getroot(), indent="    ", max_level=3)
+        self.document.write(out, pretty_print=False, xml_declaration=False,
+                            encoding='utf-8')
+
     def parse(self, xml):
         """Populates this object from the given xml string"""
         if not hasattr(self, 'filename'):
@@ -485,7 +484,7 @@ class AndroidResourceFile(lisa.LISAfile):
         if target_lang is None and hasattr(self, 'filename') and self.filename:
             # Android standards expect resource files to be in a directory named "values[-<lang>[-r<region>]]".
             parent_dir = os.path.split(os.path.dirname(self.filename))[1]
-            match = re.search('^values-(\w*)', parent_dir)
+            match = re.search(r'^values-(\w*)', parent_dir)
             if match is not None:
                 target_lang = match.group(1)
             elif parent_dir == 'values':
