@@ -28,6 +28,7 @@ except ImportError:
     import pickle
 from io import BytesIO
 
+from translate.misc.deprecation import deprecated
 from translate.misc.multistring import multistring
 from translate.storage.placeables import StringElem, parse as rich_parse
 from translate.storage.workflow import StateEnum as states
@@ -176,24 +177,47 @@ class TranslationUnit(object):
             return [rich_parse(s, self.rich_parsers) for s in mulstring.strings]
         return [rich_parse(mulstring, self.rich_parsers)]
 
-    def setsource(self, source):
+    @property
+    def source(self):
+        return self._source
+
+    @source.setter
+    def source(self, source):
         """Set the source string to the given value."""
         self._rich_source = None
         self._source = source
-    source = property(lambda self: self._source, setsource)
 
-    def settarget(self, target):
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def setsource(self, source):
+        self.source = source
+
+    @property
+    def target(self):
+        return self._target
+
+    @target.setter
+    def target(self, target):
         """Set the target string to the given value."""
         self._rich_target = None
         self._target = target
-    target = property(lambda self: self._target, settarget)
 
-    def _get_rich_source(self):
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
+    def settarget(self, target):
+        self.target = target
+
+    @property
+    def rich_source(self):
+        """
+        .. seealso:: :meth:`.rich_to_multistring`, :meth:`multistring_to_rich`
+        """
         if self._rich_source is None:
             self._rich_source = self.multistring_to_rich(self.source)
         return self._rich_source
 
-    def _set_rich_source(self, value):
+    @rich_source.setter
+    def rich_source(self, value):
         if not hasattr(value, '__iter__'):
             raise ValueError('value must be iterable')
         if len(value) < 1:
@@ -204,17 +228,18 @@ class TranslationUnit(object):
         multi = self.rich_to_multistring(value)
         if self.source != multi:
             self.source = multi
-    rich_source = property(_get_rich_source, _set_rich_source)
-    """
-    .. seealso:: :meth:`.rich_to_multistring`, :meth:`multistring_to_rich`
-    """
 
-    def _get_rich_target(self):
+    @property
+    def rich_target(self):
+        """
+        .. seealso:: :meth:`.rich_to_multistring`, :meth:`.multistring_to_rich`
+        """
         if self._rich_target is None:
             self._rich_target = self.multistring_to_rich(self.target)
         return self._rich_target
 
-    def _set_rich_target(self, value):
+    @rich_target.setter
+    def rich_target(self, value):
         if not hasattr(value, '__iter__'):
             raise ValueError('value must be iterable')
         if len(value) < 1:
@@ -223,10 +248,6 @@ class TranslationUnit(object):
             raise ValueError('value[0] must be of type StringElem.')
         self._rich_target = list(value)
         self.target = self.rich_to_multistring(value)
-    rich_target = property(_get_rich_target, _set_rich_target)
-    """
-    .. seealso:: :meth:`.rich_to_multistring`, :meth:`.multistring_to_rich`
-    """
 
     def gettargetlen(self):
         """Returns the length of the target string.
@@ -334,7 +355,7 @@ class TranslationUnit(object):
         else:
             self.notes = text
 
-    def removenotes(self):
+    def removenotes(self, origin=None):
         """Remove all the translator's notes."""
         self.notes = u''
 
@@ -675,11 +696,10 @@ class TranslationStore(object):
             insert_unit(unit.source)
 
         for location in unit.getlocations():
-            if location in self.locationindex:
-                # if sources aren't unique, don't use them
-                #FIXME: maybe better store a list of units like sourceindex
-                self.locationindex[location] = None
-            else:
+            # If locations aren't unique, keep the first unit.
+            if location not in self.locationindex:
+                #FIXME: maybe better store a list of units like sourceindex in
+                # case there are several units with the same location.
                 self.locationindex[location] = unit
 
     def makeindex(self):
@@ -744,8 +764,9 @@ class TranslationStore(object):
         """
         fileobj = getattr(self, "fileobj", None)
         if fileobj:
-            filename = getattr(fileobj, "name",
-                               getattr(fileobj, "filename", None))
+            filename = getattr(fileobj, "name", None)
+            if not filename:
+                filename = getattr(fileobj, "filename", None)
             if filename:
                 self.filename = filename
 
@@ -753,11 +774,10 @@ class TranslationStore(object):
     def parsestring(cls, storestring):
         """Convert the string representation back to an object."""
         newstore = cls()
-        if storestring:
-            if isinstance(storestring, six.text_type):
-                # parse() is expecting bytes
-                storestring = storestring.encode(cls.default_encoding)
-            newstore.parse(storestring)
+        if isinstance(storestring, six.text_type):
+            # parse() is expecting bytes
+            storestring = storestring.encode(cls.default_encoding)
+        newstore.parse(storestring)
         return newstore
 
     def fallback_detection(self, text):
@@ -874,9 +894,10 @@ class TranslationStore(object):
         if mode == 1 or "r" in mode:
             storestring = storefile.read()
             storefile.close()
+            newstore = cls.parsestring(storestring)
         else:
             storestring = ""
-        newstore = cls.parsestring(storestring)
+            newstore = cls()
         newstore.fileobj = storefile
         newstore._assignname()
         return newstore
