@@ -48,6 +48,38 @@ po_unescape_map = {"\\r": "\r", "\\t": "\t", '\\"': '"', '\\n': '\n', '\\\\': '\
 po_escape_map = dict([(value, key) for (key, value) in po_unescape_map.items()])
 
 
+def splitlines(text):
+    """Split lines based on first newline char.
+
+    Can not use univerzal newlines as they match any newline like
+    character inside text and that breaks on files with unix newlines
+    and LF chars inside comments.
+
+    The code looks for first msgid and looks for newline used after it. This
+    should safely cover weird newlines used in comments or filenames, while
+    properly parsing po files with any newlines.
+    """
+    # Strip UTF-8 BOM if present. This file would not be accepted
+    # by gettext, but some editors might create it, so better handle it.
+    if text[:3] == b'\xEF\xBB\xBF':
+        text = text[3:]
+    # Find first newline
+    newline = b'\n'
+    msgid_pos = max(0, text.find(b'msgid'))
+    for i, ch in enumerate(text[msgid_pos:]):
+        # Iteration over bytes yields numbers in Python 3
+        if ch in ('\n', 10):
+            break
+        if ch in ('\r', 13):
+            if text[msgid_pos + i + 1] in ('\n', 10):
+                newline = b'\r\n'
+            else:
+                newline = b'\r'
+            break
+
+    return [x + newline for x in text.split(newline)]
+
+
 def escapeforpo(line):
     """Escapes a line for po format. assumes no \n occurs in the line.
 
@@ -253,18 +285,24 @@ class pounit(pocommon.pounit):
             msgid_plural = []
         return msgid, msgid_plural
 
-    def getsource(self):
+    @property
+    def source(self):
         """Returns the unescaped msgid"""
         return self._get_source_vars(self.msgid, self.msgid_plural)
 
-    def setsource(self, source):
+    @source.setter
+    def source(self, source):
         """Sets the msgid to the given (unescaped) value.
 
         :param source: an unescaped source string.
         """
         self._rich_source = None
         self.msgid, self.msgid_plural = self._set_source_vars(source)
-    source = property(getsource, setsource)
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
 
     def _get_prev_source(self):
         """Returns the unescaped msgid"""
@@ -278,14 +316,16 @@ class pounit(pocommon.pounit):
         self.prev_msgid, self.prev_msgid_plural = self._set_source_vars(source)
     prev_source = property(_get_prev_source, _set_prev_source)
 
-    def gettarget(self):
+    @property
+    def target(self):
         """Returns the unescaped msgstr"""
         if isinstance(self.msgstr, dict):
             return multistring(list(map(unquotefrompo, self.msgstr.values())))
         else:
             return unquotefrompo(self.msgstr)
 
-    def settarget(self, target):
+    @target.setter
+    def target(self, target):
         """Sets the msgstr to the given (unescaped) value"""
         self._rich_target = None
         if isinstance(target, bytes):
@@ -310,7 +350,11 @@ class pounit(pocommon.pounit):
             self.msgstr = dict([(i, self.quote(targetstring)) for i, targetstring in six.iteritems(target)])
         else:
             self.msgstr = self.quote(target)
-    target = property(gettarget, settarget)
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
+    def gettarget(self):
+        return self.target
 
     def getalttrans(self):
         """Return a list of alternate units.
@@ -374,7 +418,7 @@ class pounit(pocommon.pounit):
         else:
             self.othercomments = newcomments
 
-    def removenotes(self):
+    def removenotes(self, origin=None):
         """Remove all the translator's notes (other comments)"""
         self.othercomments = []
 
@@ -587,7 +631,7 @@ class pounit(pocommon.pounit):
         return len(self.msgid_plural) > 0
 
     def parse(self, src):
-        return poparser.parse_unit(poparser.ParseState(src.splitlines(True), pounit), self)
+        return poparser.parse_unit(poparser.ParseState(splitlines(src), pounit), self)
 
     def _getmsgpartstr(self, partname, partlines, partcomments=""):
         if isinstance(partlines, dict):
@@ -775,7 +819,7 @@ class pofile(pocommon.pofile):
             self.filename = ''
         if not isinstance(input, bytes):
             input = input.read()
-        input = iter(input.splitlines(True))
+        input = iter(splitlines(input))
         # clear units to get rid of automatically generated headers before parsing
         self.units = []
         poparser.parse_units(poparser.ParseState(input, self.create_unit), self)
