@@ -62,7 +62,7 @@ def test_php_escaping_double_quote():
     assert php.phpdecode(r'\"', quotechar='"') == '"'       # See table of escaped characters
     assert php.phpdecode(r'\117\143\164\141\154', quotechar='"') == 'Octal'       # Octal: \[0-7]{1,3}
     assert php.phpdecode(r'\x48\x65\x78', quotechar='"') == 'Hex'                 # Hex: \x[0-9A-Fa-f]{1,2}
-    assert php.phpdecode(r'\117\\c\164\141\154', quotechar='"') == 'O\ctal'  # Mixed
+    assert php.phpdecode(r'\117\\c\164\141\154', quotechar='"') == r'O\ctal'  # Mixed
     # Decoding - special examples
     assert php.phpdecode(r"Don't escape me here\'s", quotechar='"') == r"Don't escape me here\'s"  # See bug #589
     assert php.phpdecode("Line1\nLine2") == "Line1\nLine2"      # Preserve newlines in multiline messages
@@ -76,7 +76,7 @@ def test_php_escaping_double_quote():
     assert php.phpencode("\f", quotechar='"') == r"\f"      # See table of escaped characters
     assert php.phpencode(r"\\", quotechar='"') == r"\\"      # See table of escaped characters
     #assert php.phpencode("\$", quotechar='"') == "$"      # See table of escaped characters - this may cause confusion with actual variables in roundtripping
-    assert php.phpencode("\$", quotechar='"') == r"\$"     # Just to check that we don't unescape this
+    assert php.phpencode(r"\$", quotechar='"') == r"\$"     # Just to check that we don't unescape this
     assert php.phpencode('"', quotechar='"') == r'\"'
     assert php.phpencode(r"Don't escape me here\'s", quotechar='"') == r"Don't escape me here\'s"  # See bug #589
 
@@ -563,18 +563,21 @@ $month_mar = 'Mar';"""
     def test_parsing_arrays_using_short_array_syntax(self):
         """parse short array syntax.
         Bug #3626"""
-        phpsource = '''$lang = [
-         'item1' => 'value1',
-         'item2' => 'value2'
-      ];'''
+        phpsource = b'''<?php
+$lang = [
+    'item1' => 'value1',
+    'item2' => 'value2',
+];
+'''
         phpfile = self.phpparse(phpsource)
         assert len(phpfile.units) == 2
         phpunit = phpfile.units[0]
-        assert phpunit.name == "$lang->'item1'"
+        assert phpunit.name == "$lang[]->'item1'"
         assert phpunit.source == "value1"
         phpunit = phpfile.units[1]
-        assert phpunit.name == "$lang->'item2'"
+        assert phpunit.name == "$lang[]->'item2'"
         assert phpunit.source == "value2"
+        assert phpfile.__bytes__() == phpsource
 
     def test_parsing_nested_arrays(self):
         """parse the nested array syntax. Bug #2240"""
@@ -669,19 +672,19 @@ $month_mar = 'Mar';"""
         phpfile = self.phpparse(phpsource)
         assert len(phpfile.units) == 8
         phpunit = phpfile.units[0]
-        assert phpunit.name == "'name1'"
+        assert phpunit.name == "return->'name1'"
         assert phpunit.source == "target1"
         phpunit = phpfile.units[1]
-        assert phpunit.name == "'list1'->'l1'"
+        assert phpunit.name == "return->'list1'->'l1'"
         assert phpunit.source == "target_l1_1"
         phpunit = phpfile.units[2]
-        assert phpunit.name == "'list1'->'l2'"
+        assert phpunit.name == "return->'list1'->'l2'"
         assert phpunit.source == "target_l1_2"
         phpunit = phpfile.units[3]
-        assert phpunit.name == "'list1'->'l3'"
+        assert phpunit.name == "return->'list1'->'l3'"
         assert phpunit.source == "target_l1_3"
         phpunit = phpfile.units[4]
-        assert phpunit.name == "'list2'->'l1'"
+        assert phpunit.name == "return->'list2'->'l1'"
         assert phpunit.source == "target_l2_1"
 
     def test_parsing_nested_arrays_with_array_declaration_in_next_line(self):
@@ -955,8 +958,43 @@ using nowdoc syntax.'''
         phpfile = self.phpparse(phpsource)
         assert len(phpfile.units) == 3
         assert phpfile.units[0].source == 'First'
-        assert phpfile.units[0].name == "$arr->'1234'"
+        assert phpfile.units[0].name == "$arr[]->'1234'"
         assert phpfile.units[1].source == 'Second'
-        assert phpfile.units[1].name == "$arr->1234"
+        assert phpfile.units[1].name == "$arr[]->1234"
         assert phpfile.units[2].source == 'Third'
-        assert phpfile.units[2].name == "$arr->'1245'"
+        assert phpfile.units[2].name == "$arr[]->'1245'"
+
+    def test_double_var(self):
+        """checks that a double $ is handled correctly"""
+        phpsource = """$$lang['mediaselect'] = 'Bestand selectie';"""
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 1
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "$$lang['mediaselect']"
+        assert phpunit.source == "Bestand selectie"
+
+    def test_return_array(self):
+        phpsource = b"""<?php
+return array(
+    'peach' => 'pesca',
+);
+"""
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 1
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "return->'peach'"
+        assert phpunit.source == "pesca"
+        assert phpfile.__bytes__() == phpsource
+
+    def test_return_array_short(self):
+        phpsource = b"""<?php
+return [
+    'peach' => 'pesca',
+];
+"""
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 1
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "return[]->'peach'"
+        assert phpunit.source == "pesca"
+        assert phpfile.__bytes__() == phpsource
