@@ -64,6 +64,51 @@ The other line&apos;s translation may have quotes, too (&quot;&apos;&quot;,
 </TS>
 """
 
+TS_CONTEXT_QT4 = """<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0" language="cs">
+<defaultcodec>UTF-8</defaultcodec>
+<context>
+    <name></name>
+    <message>
+        <source>Hello, world!</source>
+        <translation>Ahoj svete!</translation>
+    </message>
+</context>
+<context>
+    <name>Second</name>
+    <message>
+        <source>Obsolete</source>
+        <translation type="obsolete">Thanks</translation>
+    </message>
+</context>
+</TS>
+"""
+
+TS_CONTEXT_QT5 = """<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="cs" sourcelanguage="en">
+<context>
+    <name></name>
+    <message>
+        <source>Hello, world!</source>
+        <translation>Ahoj svete!</translation>
+    </message>
+</context>
+<context>
+    <name>Second</name>
+    <message>
+        <source>Obsolete</source>
+        <translation type="vanished">Thanks</translation>
+    </message>
+    <message>
+        <source>Vanished</source>
+        <translation type="vanished">Thanks a lot</translation>
+    </message>
+</context>
+</TS>
+"""
+
 xliffparsers = []
 for attrname in dir(xliff):
     attr = getattr(xliff, attrname)
@@ -172,6 +217,20 @@ class TestTSfile(test_base.TestTranslationStore):
         )
         assert newtsstr == bytes(tsfile).decode('utf-8')
 
+    def test_obsolete(self):
+        tsfile = ts.tsfile.parsestring(TS_CONTEXT_QT4)
+        assert tsfile.units[0].istranslatable()
+        assert not tsfile.units[0].isobsolete()
+        assert not tsfile.units[1].istranslatable()
+        assert tsfile.units[1].isobsolete()
+        tsfile = ts.tsfile.parsestring(TS_CONTEXT_QT5)
+        assert tsfile.units[0].istranslatable()
+        assert not tsfile.units[0].isobsolete()
+        assert not tsfile.units[1].istranslatable()
+        assert tsfile.units[1].isobsolete()
+        assert not tsfile.units[2].istranslatable()
+        assert tsfile.units[2].isobsolete()
+
     def test_locations(self):
         """test that locations work well"""
         tsstr = '''<?xml version="1.0" encoding="utf-8"?>
@@ -293,3 +352,9 @@ class TestTSfile(test_base.TestTranslationStore):
         assert newunit.getcontext() == ""
         newunit.setcontext("Some context")
         assert newunit.getcontext() == "Some context"
+
+    def test_roundtrip_context(self):
+        tsfile = ts.tsfile.parsestring(TS_CONTEXT_QT4)
+        assert bytes(tsfile).decode('utf-8') == TS_CONTEXT_QT4
+        tsfile = ts.tsfile.parsestring(TS_CONTEXT_QT5)
+        assert bytes(tsfile).decode('utf-8') == TS_CONTEXT_QT5
