@@ -29,6 +29,13 @@ class TestYAMLResourceStore(test_monolingual.TestMonolingualStore):
         store.serialize(out)
         assert out.getvalue() == b'key: value\n'
 
+    def test_empty(self):
+        store = self.StoreClass()
+        store.parse('{}')
+        out = BytesIO()
+        store.serialize(out)
+        assert out.getvalue() == b'{}\n'
+
     def test_edit(self):
         store = self.StoreClass()
         store.parse('key: value')
@@ -88,7 +95,7 @@ foo: bar
         assert store.units[0].source == 'Oficina'
         out = BytesIO()
         store.serialize(out)
-        assert out.getvalue() == b''''yes': Oficina
+        assert out.getvalue() == b'''yes: Oficina
 '''
 
     def test_nested(self):
@@ -371,6 +378,17 @@ foo:
   : Dve
 '''
 
+    def test_dict_in_list(self):
+        data = '''e1:
+- s1: Subtag 1
+'''
+        store = self.StoreClass()
+        store.parse(data)
+        assert len(store.units) == 1
+        out = BytesIO()
+        store.serialize(out)
+        assert out.getvalue() == data.encode('ascii')
+
 
 class TestRubyYAMLResourceStore(test_monolingual.TestMonolingualStore):
     StoreClass = yaml.RubyYAMLFile
@@ -414,9 +432,29 @@ class TestRubyYAMLResourceStore(test_monolingual.TestMonolingualStore):
     def test_invalid_key(self):
         store = yaml.YAMLFile()
         with pytest.raises(base.ParseError):
-            store.parse('yes: string')
+            store.parse('1: string')
 
     def test_invalid_value(self):
         store = yaml.YAMLFile()
         with pytest.raises(base.ParseError):
             store.parse('val: "\\u string"')
+
+    def test_ruby_plural(self):
+        data = '''en:
+  message:
+    one: There is one message
+    other: There are %{count} messages
+'''
+        store = self.StoreClass()
+        store.parse(data)
+        assert len(store.units) == 1
+        out = BytesIO()
+        store.serialize(out)
+        assert out.getvalue() == data.encode('ascii')
+
+    def test_empty(self):
+        store = self.StoreClass()
+        store.parse('{}')
+        out = BytesIO()
+        store.serialize(out)
+        assert out.getvalue() == b'{}\n'
