@@ -24,76 +24,17 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 
 import uuid
-from collections import OrderedDict
 
 import six
-import yaml
-import yaml.constructor
+from ruamel.yaml import YAML, YAMLError
+from ruamel.yaml.comments import CommentedMap
 
+from translate.lang.data import cldr_plural_categories, plural_tags
 from translate.misc.deprecation import deprecated
+from translate.misc.multistring import multistring
 from translate.storage import base
 
 
-class OrderedDictYAMLLoader(yaml.SafeLoader):
-    """
-    A YAML loader that loads mappings into ordered dictionaries.
-    """
-
-    def __init__(self, *args, **kwargs):
-        yaml.SafeLoader.__init__(self, *args, **kwargs)
-
-        self.add_constructor(u'tag:yaml.org,2002:map', type(self).construct_yaml_map)
-        self.add_constructor(u'tag:yaml.org,2002:omap', type(self).construct_yaml_map)
-
-    def construct_yaml_map(self, node):
-        data = OrderedDict()
-        yield data
-        value = self.construct_mapping(node)
-        data.update(value)
-
-    def construct_mapping(self, node, deep=False):
-        if isinstance(node, yaml.MappingNode):
-            self.flatten_mapping(node)
-        else:
-            raise yaml.constructor.ConstructorError(
-                None, None,
-                'expected a mapping node, but found %s' % node.id, node.start_mark
-            )
-
-        mapping = OrderedDict()
-        for key_node, value_node in node.value:
-            key = self.construct_object(key_node, deep=deep)
-            try:
-                hash(key)
-            except TypeError as exc:
-                raise yaml.constructor.ConstructorError(
-                    'while constructing a mapping',
-                    node.start_mark,
-                    'found unacceptable key (%s)' % exc, key_node.start_mark
-                )
-            value = self.construct_object(value_node, deep=deep)
-            mapping[key] = value
-        return mapping
-
-
-class UnsortableList(list):
-    def sort(self, *args, **kwargs):
-        pass
-
-
-class UnsortableOrderedDict(OrderedDict):
-    def items(self, *args, **kwargs):
-        return UnsortableList(OrderedDict.items(self, *args, **kwargs))
-
-
-class YAMLDumper(yaml.SafeDumper):
-    def represent_unsorted(self, data):
-        return self.represent_dict(data.items())
-
-
-YAMLDumper.add_representer(UnsortableOrderedDict, YAMLDumper.represent_unsorted)
-
-
 class YAMLUnit(base.TranslationUnit):
     """A YAML entry"""
 
@@ -146,43 +87,54 @@ class YAMLFile(base.TranslationStore):
         """Returns root node for serialize"""
         return node
 
+    def serialize_value(self, value):
+        return value
+
     def serialize(self, out):
         def nested_set(target, path, value):
+            value = self.serialize_value(value)
             if len(path) > 1:
-                if len(path) == 2 and path[1] and path[1][0] == '[' and path[1][-1] == ']' and path[1][1:-1].isdigit():
+                if len(path) >= 2 and path[1] and path[1][0] == '[' and path[1][-1] == ']' and path[1][1:-1].isdigit():
                     if path[0] not in target:
                         target[path[0]] = []
-                    target[path[0]].append(value)
+                    if len(path) > 2:
+                        new_value = CommentedMap()
+                        nested_set(new_value, path[2:], value)
+                        target[path[0]].append(new_value)
+                    else:
+                        target[path[0]].append(value)
                 else:
                     # Add empty dict in case there is value and we
                     # expect dict
                     if path[0] not in target or not isinstance(target[path[0]], dict):
-                        target[path[0]] = UnsortableOrderedDict()
+                        target[path[0]] = CommentedMap()
                     nested_set(target[path[0]], path[1:], value)
             else:
                 target[path[0]] = value
 
-        units = UnsortableOrderedDict()
+        units = CommentedMap()
         for unit in self.unit_iter():
             nested_set(units, unit.getid().split('->'), unit.target)
-        out.write(yaml.dump_all(
-            [self.get_root_node(units)],
-            Dumper=YAMLDumper,
-            default_flow_style=False, encoding='utf-8', allow_unicode=True
-        ))
+        yaml = YAML()
+        yaml.default_flow_style = False
+        yaml.dump(self.get_root_node(units), out)
+
+    def _parse_dict(self, data, prev):
+        for k, v in six.iteritems(data):
+            if not isinstance(k, six.string_types):
+                raise base.ParseError(
+                    'Key not string: {0}/{1} ({2})'.format(prev, k, type(k))
+                )
+
+            for x in self._flatten(v, '->'.join((prev, k)) if prev else k):
+                yield x
 
     def _flatten(self, data, prev=""):
         """Flatten YAML dictionary.
         """
         if isinstance(data, dict):
-            for k, v in six.iteritems(data):
-                if not isinstance(k, six.string_types):
-                    raise base.ParseError(
-                        'Key not string: {0}/{1} ({2})'.format(prev, k, type(k))
-                    )
-
-                for x in self._flatten(v, '->'.join((prev, k)) if prev else k):
-                    yield x
+            for x in self._parse_dict(data, prev):
+                yield x
         else:
             if isinstance(data, six.string_types):
                 yield (prev, data)
@@ -191,7 +143,8 @@ class YAMLFile(base.TranslationStore):
             elif isinstance(data, list):
                 for k, v in enumerate(data):
                     key = '[{0}]'.format(k)
-                    yield ('->'.join((prev, key)), six.text_type(v))
+                    for value in self._flatten(v, '->'.join((prev, key))):
+                        yield value
             elif data is None:
                 pass
             else:
@@ -216,9 +169,10 @@ class YAMLFile(base.TranslationStore):
             input = src
         if isinstance(input, bytes):
             input = input.decode('utf-8')
+        yaml = YAML()
         try:
-            self._file = yaml.load(input, OrderedDictYAMLLoader)
-        except yaml.YAMLError as e:
+            self._file = yaml.load(input)
+        except YAMLError as e:
             message = e.problem if hasattr(e, 'problem') else e.message
             if hasattr(e, 'problem_mark'):
                 message += ' {0}'.format(e.problem_mark)
@@ -236,7 +190,7 @@ class RubyYAMLFile(YAMLFile):
     """Ruby YAML file, it has language code as first node."""
 
     def preprocess(self, data):
-        if isinstance(data, OrderedDict) and len(data) == 1:
+        if isinstance(data, CommentedMap) and len(data) == 1:
             lang = list(data.keys())[0]
             self.settargetlanguage(lang)
             return data[lang]
@@ -245,7 +199,34 @@ class RubyYAMLFile(YAMLFile):
     def get_root_node(self, node):
         """Returns root node for serialize"""
         if self.targetlanguage is not None:
-            result = UnsortableOrderedDict()
+            result = CommentedMap()
             result[self.targetlanguage] = node
             return result
         return node
+
+    def _parse_dict(self, data, prev):
+        # Does this look like a plural?
+        if data and all((x in cldr_plural_categories for x in data.keys())):
+            # Ensure we have correct plurals ordering.
+            values = [data[item] for item in cldr_plural_categories if item in data]
+            yield (prev, multistring(values))
+            return
+
+        # Handle normal dict
+        for x in super(RubyYAMLFile, self)._parse_dict(data, prev):
+            yield x
+
+    def serialize_value(self, value):
+        if not isinstance(value, multistring):
+            return value
+
+        tags = plural_tags.get(self.targetlanguage, plural_tags['en'])
+
+        strings = [six.text_type(s) for s in value.strings]
+
+        # Sync plural_strings elements to plural_tags count.
+        if len(strings) < len(tags):
+            strings += [''] * (len(tags) - len(strings))
+        strings = strings[:len(tags)]
+
+        return CommentedMap(zip(tags, strings))
